@@ -22,8 +22,13 @@
 
 #include <curl/curl.h>
 
+#if HAVE_INTTYPES_H
+# include <inttypes.h>
+#elif HAVE_STDINT_H
+# include <stdint.h>
+#endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+# include <unistd.h>
 #endif
 
 #include "webauth.h"
@@ -140,6 +145,7 @@
 
 #define CD_ExtraRedirect "WebAuthExtraRedirect"
 #define CM_ExtraRedirect "do extra redirect after getting returned from WebKDC"
+#define DF_ExtraRedirect 1
 
 #define CD_InactiveExpire "WebAuthInactiveExpire"
 #define CM_InactiveExpire "duration of inactivity before an app-token expires"
@@ -289,7 +295,7 @@ typedef struct {
     apr_pool_t *pool; /* pool this token belongs to */
     WEBAUTH_KEY key;
     time_t expires;
-    unsigned char *token;
+    char *token;
     time_t created; /* when we first obtained this token */
     time_t next_renewal_attempt; /* next time we try to renew */
     time_t last_renewal_attempt; /* time we last tried to renew */
@@ -319,6 +325,8 @@ typedef struct {
     int ssl_redirect_ex;
     int ssl_redirect_port;
     int ssl_redirect_port_ex;
+    int extra_redirect;
+    int extra_redirect_ex; /* if it was explicitly specified in conf file */
     char *subject_auth_type;
     int strip_url;
     int strip_url_ex; 
